Order class
Constructors
-
Order({required String orderCode, required int finalPrice, required int state, required int discount, required DateTime createdAt, required int paymentMethod, DateTime? paymentTime, required int deliveryMethod, DateTime? deliveredTime, required String deliveryAddress, required List<
OrderItem> items})
Properties
- createdAt → DateTime
-
final
- deliveredTime → DateTime?
-
final
- deliveryAddress → String
-
final
- deliveryMethod → int
-
final
- discount → int
-
final
- finalPrice → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
OrderItem> -
final
- orderCode → String
-
final
- paymentMethod → int
-
final
- paymentTime → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited